"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const unirest = require("unirest");
const API_ENDPOINT = "https://api.remove.bg/v1.0/removebg";
const API_KEY_HEADER = "X-Api-Key";
function removeBackgroundFromImageUrl(options) {
    return new Promise((resolve, reject) => {
        getPost(options)
            .header("Content-Type", "application/json")
            .send({
            "image_url": options.url,
            "size": options.size || "regular"
        })
            .end(result => processResult(result, options, resolve, reject));
    });
}
exports.removeBackgroundFromImageUrl = removeBackgroundFromImageUrl;
function removeBackgroundFromImageFile(options) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((resolve, reject) => {
            getPost(options)
                .field("size", options.size || "regular")
                .attach("image_file", fs.createReadStream(options.path))
                .end(result => processResult(result, options, resolve, reject));
        });
    });
}
exports.removeBackgroundFromImageFile = removeBackgroundFromImageFile;
function removeBackgroundFromImageBase64(options) {
    return new Promise((resolve, reject) => {
        getPost(options)
            .header("Content-Type", "application/json")
            .send({
            "image_file_b64": options.base64img,
            "size": options.size || "regular"
        })
            .end(result => processResult(result, options, resolve, reject));
    });
}
exports.removeBackgroundFromImageBase64 = removeBackgroundFromImageBase64;
function getPost(options) {
    return unirest
        .post(API_ENDPOINT)
        .header(API_KEY_HEADER, options.apiKey)
        .header("Accept", "application/json");
}
function processResult(result, options, resolve, reject) {
    return __awaiter(this, void 0, void 0, function* () {
        if (result.status === 200) {
            if (options.outputFile) {
                fs.writeFileSync(options.outputFile, result.body.data.result_b64, { encoding: "base64" });
            }
            resolve({
                base64img: result.body.data.result_b64
            });
        }
        else {
            reject((result.body.errors ? result.body.errors : result.body));
        }
    });
}
